/* 
 * Copyright (C) 1999 JP Rosevear
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
 */

#ifndef TIMER_H
#define TIMER_H

#include <gtk/gtk.h>

#define TIMER(obj)	GTK_CHECK_CAST (obj, timer_get_type(), Timer)
#define TIMER_CLASS(klass)  GTK_CHECK_CLASS_CAST (klass, timer_get_type(), TimerClass)
#define IS_TIMER(obj)       GTK_CHECK_TYPE (obj, timer_get_type())

typedef struct _Timer       Timer;
typedef struct _TimerClass  TimerClass;

struct _TimerClass {
	GtkLabelClass parent_class;

	void (*expired) (Timer *timer);
};

struct _Timer {
	GtkLabel label;

	gint sec;
	guint handlerid;
};

GtkType timer_get_type (void);
GtkWidget* timer_new (gint secs);
gint timer_get(Timer *timer);
void timer_set(Timer *timer, gint secs);
void timer_start(Timer *timer);
void timer_stop(Timer *timer);

#endif
